Backends — django-userena 1.0.2 documentation

### Navigation

- index
- next |
- previous |
- django-userena 1.0.2 documentation »
- API Reference »

# Backends

Return to API Reference.

#### Previous topic

API Reference

#### Next topic

Decorators

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- next |
- previous |
- django-userena 1.0.2 documentation »
- API Reference »

© Copyright 2010, 2011 Bread & Pepper. Created using Sphinx 1.1.3.